@@ -6,11 +6,15 @@
 		res <- as.data.frame(res)
 		res <- cbind(res,as.factor(object@chromosome))
 		if (any(object@chromosome == "X")) {
-		  oX <- object[(object@male != 1),(object@chromosome == "X")]
-		  resX <- .C("snp_summary_exhwe",as.raw(oX@gtps),as.integer(oX@nids),as.integer(oX@nsnps), out = double(oX@nsnps*7), PACKAGE="GenABEL")$out
 		  vec <- (object@chromosome == "X")
-		  res[vec,7] <- resX[(oX@nsnps*6+1):(oX@nsnps*7)]
-		  rm(oX,vec,resX);gc(verbose=FALSE)
+		  if (any(object@male == 0)) {
+ 		    oX <- object[(object@male != 1),(object@chromosome == "X")]
+		    resX <- .C("snp_summary_exhwe",as.raw(oX@gtps),as.integer(oX@nids),as.integer(oX@nsnps), out = double(oX@nsnps*7), PACKAGE="GenABEL")$out
+		    res[vec,7] <- resX[(oX@nsnps*6+1):(oX@nsnps*7)]
+		    rm(oX,vec,resX);gc(verbose=FALSE)
+		  } else {
+		    res[vec,7] <- rep(1,sum(vec))
+		  }
 		}
 		rownames(res) <- object@snpnames
 		colnames(res) <- c("NoMeasured","CallRate","Q.2","P.11","P.12","P.22","Pexact","Chromosome")
